==> graph-0.2.0.tgz: package/src/components/nodes.jsx <==
import React, { useContext, useEffect } from 'react'
import PropTypes from 'prop-types'
import { GraphContext, getRelativePosition } from '../utils/index.js'
import * as d3 from 'd3-selection'


const Nodes = ({
    radius = 20,
    fill = '#fff',
    selectedFill = '#333',
    shadowColor = '#999',
    shadowBlur = 5,
    image,
    children = null,
    onMouseOver,
    onMouseOut,
    onMouseMove
}) => {
    const {canvas, simulation, nodes} = useContext(GraphContext)

    useEffect(() => {
        const container = d3.select(canvas.current)
        const ctx = canvas.current.getContext('2d')
        let hovered = null

        simulation.on('tick.nodes', () => {
            const { transform } = simulation

            ctx.save()

            if (transform) {
                ctx.translate(transform.x, transform.y)
                ctx.scale(transform.k, transform.k)
            }

            nodes.forEach(d => {
                ctx.beginPath()
                ctx.moveTo(d.x + radius, d.y)
                ctx.arc(d.x, d.y, radius, 0, 2 * Math.PI)
                ctx.shadowColor = shadowColor
                ctx.shadowBlur = shadowBlur
                ctx.fillStyle = d.selected ? selectedFill : fill
                ctx.fill()

                if (image) {
                    const data = image(d)

                    if (data) {
                        ctx.shadowBlur = 0
                        ctx.drawImage(
                            data.element,
                            d.x + data.x,
                            d.y + data.y,
                            data.width,
                            data.height
                        )
                    }
                }
            })

            ctx.restore()
        })

        container.on('mousemove.nodes', () => {
            const {x: rawX, y: rawY} = d3.event
            const {transform} = simulation
            const {x, y} = getRelativePosition(rawX, rawY, canvas.current)
            const transformed = transform.invert([x, y])
            const node = simulation.find(...transformed, 20) || null

            if (!hovered && node && onMouseOver) onMouseOver(node)
            if (hovered && !node && onMouseOut) onMouseOut(node)
            if (onMouseMove) onMouseMove(node, {x, y})

            hovered = node
        })
    })

    return children
}

Nodes.propTypes = {
    radius: PropTypes.number,
    fill: PropTypes.string,
    image: PropTypes.func,
    children: PropTypes.node,
    onMouseOver: PropTypes.func,
    onMouseOut: PropTypes.func,
    onMouseMove: PropTypes.func
}

export default Nodes

==> graph-0.2.2.tgz: package/src/components/nodes.jsx <==
import React, { useContext, useEffect } from 'react'
import PropTypes from 'prop-types'
import { GraphContext, getRelativePosition, isVisible } from '../utils/index.js'
import * as d3 from 'd3-selection'


const Nodes = ({
    radius = 20,
    fill = '#fff',
    selectedFill = '#333',
    shadowColor = '#999',
    shadowBlur = 5,
    image,
    children = null,
    onMouseOver,
    onMouseOut,
    onMouseMove
}) => {
    const {canvas, simulation, nodes, bounds} = useContext(GraphContext)

    useEffect(() => {
        const container = d3.select(canvas.current)
        const ctx = canvas.current.getContext('2d')
        let hovered = null

        simulation.on('tick.nodes', () => {
            const { transform } = simulation

            ctx.save()

            if (transform) {
                ctx.translate(transform.x, transform.y)
                ctx.scale(transform.k, transform.k)
            }

            nodes.forEach(d => {
                if (!isVisible(d, transform, bounds)) return

                ctx.beginPath()
                ctx.moveTo(d.x + radius, d.y)
                ctx.arc(d.x, d.y, radius, 0, 2 * Math.PI)
                ctx.shadowColor = shadowColor
                ctx.shadowBlur = shadowBlur
                ctx.fillStyle = d.selected ? selectedFill : fill
                ctx.fill()

                if (image) {
                    const data = image(d)

                    if (data) {
                        ctx.shadowBlur = 0
                        ctx.drawImage(
                            data.element,
                            d.x + data.x,
                            d.y + data.y,
                            data.width,
                            data.height
                        )
                    }
                }
            })

            ctx.restore()
        })

        container.on('mousemove.nodes', () => {
            const {x: rawX, y: rawY} = d3.event
            const {transform} = simulation
            const {x, y} = getRelativePosition(rawX, rawY, canvas.current)
            const transformed = transform.invert([x, y])
            const node = simulation.find(...transformed, 20) || null

            if (!hovered && node && onMouseOver) onMouseOver(node)
            if (hovered && !node && onMouseOut) onMouseOut(node)
            if (onMouseMove) onMouseMove(node, {x, y})

            hovered = node
        })
    })

    return children
}

Nodes.propTypes = {
    radius: PropTypes.number,
    fill: PropTypes.string,
    image: PropTypes.func,
    children: PropTypes.node,
    onMouseOver: PropTypes.func,
    onMouseOut: PropTypes.func,
    onMouseMove: PropTypes.func
}

export default Nodes
